==> apache-polaris-1.1.0-incubating.tar.gz: apache-polaris-1.1.0-incubating/polaris-core/src/main/java/org/apache/polaris/core/persistence/resolver/ResolutionManifestFactoryImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.polaris.core.persistence.resolver;

import jakarta.annotation.Nonnull;
import jakarta.annotation.Nullable;
import jakarta.ws.rs.core.SecurityContext;
import org.apache.polaris.core.context.CallContext;

public class ResolutionManifestFactoryImpl implements ResolutionManifestFactory {

  private final ResolverFactory resolverFactory;

  public ResolutionManifestFactoryImpl(@Nonnull ResolverFactory resolverFactory) {
    this.resolverFactory = resolverFactory;
  }

  @Nonnull
  @Override
  public PolarisResolutionManifest createResolutionManifest(
      @Nonnull CallContext callContext,
      @Nonnull SecurityContext securityContext,
      @Nullable String referenceCatalogName) {
    return new PolarisResolutionManifest(
        callContext, resolverFactory, securityContext, referenceCatalogName);
  }
}

==> apache-polaris-1.2.0-incubating.tar.gz: apache-polaris-1.2.0-incubating/polaris-core/src/main/java/org/apache/polaris/core/persistence/resolver/ResolutionManifestFactoryImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.polaris.core.persistence.resolver;

import jakarta.annotation.Nonnull;
import jakarta.annotation.Nullable;
import jakarta.ws.rs.core.SecurityContext;
import org.apache.polaris.core.PolarisDiagnostics;
import org.apache.polaris.core.context.RealmContext;

public class ResolutionManifestFactoryImpl implements ResolutionManifestFactory {

  private final PolarisDiagnostics diagnostics;
  private final RealmContext realmContext;
  private final ResolverFactory resolverFactory;

  public ResolutionManifestFactoryImpl(
      @Nonnull PolarisDiagnostics diagnostics,
      @Nonnull RealmContext realmContext,
      @Nonnull ResolverFactory resolverFactory) {
    this.diagnostics = diagnostics;
    this.realmContext = realmContext;
    this.resolverFactory = resolverFactory;
  }

  @Nonnull
  @Override
  public PolarisResolutionManifest createResolutionManifest(
      @Nonnull SecurityContext securityContext, @Nullable String referenceCatalogName) {
    return new PolarisResolutionManifest(
        diagnostics, realmContext, resolverFactory, securityContext, referenceCatalogName);
  }
}
